aboutsummaryrefslogtreecommitdiffhomepage
path: root/src/google/protobuf/map_test_util.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/google/protobuf/map_test_util.h')
-rw-r--r--src/google/protobuf/map_test_util.h9
1 files changed, 8 insertions, 1 deletions
diff --git a/src/google/protobuf/map_test_util.h b/src/google/protobuf/map_test_util.h
index 653cf107..f437e33e 100644
--- a/src/google/protobuf/map_test_util.h
+++ b/src/google/protobuf/map_test_util.h
@@ -40,9 +40,12 @@ namespace unittest = ::protobuf_unittest;
class MapTestUtil {
public:
// Set every field in the message to a unique value.
static void SetMapFields(unittest::TestMap* message);
+ // Set every field in the TestArenaMap message to a unique value.
+ static void SetArenaMapFields(unittest::TestArenaMap* message);
+
// Set every field in the message to a default value.
static void SetMapFieldsInitialized(unittest::TestMap* message);
@@ -55,6 +58,10 @@ class MapTestUtil {
static void ExpectMapFieldsSet(const unittest::TestMap& message);
// Check that all fields have the values that they should have after
+ // SetMapFields() is called for TestArenaMap.
+ static void ExpectArenaMapFieldsSet(const unittest::TestArenaMap& message);
+
+ // Check that all fields have the values that they should have after
// SetMapFieldsInitialized() is called.
static void ExpectMapFieldsSetInitialized(
const unittest::TestMap& message);
@@ -40,9 +40,12 @@ namespace unittest = ::protobuf_unittest;
class MapTestUtil {
public:
- // Set every field in the message to a unique value.
+ // Set every field in the TestMap message to a unique value.
static void SetMapFields(unittest::TestMap* message);